==> applet-service-2.0.0-20200812.035905-16-sources.jar: com/bizvane/appletservice/models/bo/AppletWxPayBo.java <==
package com.bizvane.appletservice.models.bo;

import java.util.Date;

public class AppletWxPayBo {
    private Long sysBrandId;
    private String memberCode;
    private Double money;
    private Date paymentDate;
    private String bizvaneSessionId;
    private String openId;
    private String appId;
    private Double giveMoney;
    private String wxPayVoucherNo;
    // ur储蓄
    private String cardStyleCode;
    // ur储蓄name
    private String name;
    //yw储值卡类型
    private Long cardType;
    //yw储值卡卡号
    private String storedCardCode;

    private String outTradeNo;

    public String getOutTradeNo() {
        return outTradeNo;
    }

    public void setOutTradeNo(String outTradeNo) {
        this.outTradeNo = outTradeNo;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCardStyleCode() {
        return cardStyleCode;
    }

    public void setCardStyleCode(String cardStyleCode) {
        this.cardStyleCode = cardStyleCode;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    // ur储蓄
    private Long sysCompanyId;

    public String getWxPayVoucherNo() {
        return wxPayVoucherNo;
    }

    public void setWxPayVoucherNo(String wxPayVoucherNo) {
        this.wxPayVoucherNo = wxPayVoucherNo;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Double getMoney() {
        return money;
    }

    public void setMoney(Double money) {
        this.money = money;
    }

    public Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(Date paymentDate) {
        this.paymentDate = paymentDate;
    }

    public String getBizvaneSessionId() {
        return bizvaneSessionId;
    }

    public void setBizvaneSessionId(String bizvaneSessionId) {
        this.bizvaneSessionId = bizvaneSessionId;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Double getGiveMoney() {
        return giveMoney;
    }

    public void setGiveMoney(Double giveMoney) {
        this.giveMoney = giveMoney;
    }

    public Long getCardType() {
        return cardType;
    }

    public void setCardType(Long cardType) {
        this.cardType = cardType;
    }

    public String getStoredCardCode() {
        return storedCardCode;
    }

    public void setStoredCardCode(String storedCardCode) {
        this.storedCardCode = storedCardCode;
    }
}

==> applet-service-2.0.0-20201010.074418-22-sources.jar: com/bizvane/appletservice/models/bo/AppletWxPayBo.java <==
package com.bizvane.appletservice.models.bo;

import java.util.Date;

public class AppletWxPayBo {
    private Long sysBrandId;
    private String memberCode;
    private Double money;
    private Date paymentDate;
    private String bizvaneSessionId;
    private String openId;
    private String appId;
    private Double giveMoney;
    private String wxPayVoucherNo;
    // ur储蓄
    private String cardStyleCode;
    // ur储蓄name
    private String name;
    //yw储值卡类型
    private Long cardType;
    //yw储值卡卡号
    private String storedCardCode;

    private String outTradeNo;
    /**
     * 门店id
     */
    private Long sysStoreId;

    public String getOutTradeNo() {
        return outTradeNo;
    }

    public void setOutTradeNo(String outTradeNo) {
        this.outTradeNo = outTradeNo;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getCardStyleCode() {
        return cardStyleCode;
    }

    public void setCardStyleCode(String cardStyleCode) {
        this.cardStyleCode = cardStyleCode;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    // ur储蓄
    private Long sysCompanyId;

    public String getWxPayVoucherNo() {
        return wxPayVoucherNo;
    }

    public void setWxPayVoucherNo(String wxPayVoucherNo) {
        this.wxPayVoucherNo = wxPayVoucherNo;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Double getMoney() {
        return money;
    }

    public void setMoney(Double money) {
        this.money = money;
    }

    public Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(Date paymentDate) {
        this.paymentDate = paymentDate;
    }

    public String getBizvaneSessionId() {
        return bizvaneSessionId;
    }

    public void setBizvaneSessionId(String bizvaneSessionId) {
        this.bizvaneSessionId = bizvaneSessionId;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Double getGiveMoney() {
        return giveMoney;
    }

    public void setGiveMoney(Double giveMoney) {
        this.giveMoney = giveMoney;
    }

    public Long getCardType() {
        return cardType;
    }

    public void setCardType(Long cardType) {
        this.cardType = cardType;
    }

    public String getStoredCardCode() {
        return storedCardCode;
    }

    public void setStoredCardCode(String storedCardCode) {
        this.storedCardCode = storedCardCode;
    }

    public Long getSysStoreId() {
        return sysStoreId;
    }

    public void setSysStoreId(Long sysStoreId) {
        this.sysStoreId = sysStoreId;
    }
}
